@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-langs.c,v 1.20 2005/12/05 20:27:19 chpe Exp $
+ *  $Id: ephy-langs.c 6588 2006-09-13 11:34:25Z chpe $
  */
 
 #include "config.h"
@@ -80,7 +80,6 @@ static const EphyFontsLanguageInfo font_languages [] =
 	/* Translators: The text before the "|" is context to help you decide on
 	 * the correct translation. You MUST OMIT it in the translated string. */
 	{ N_("select fonts for|Turkish"),				"tr" },
-#ifdef HAVE_GECKO_1_8
 	/* Translators: The text before the "|" is context to help you decide on
 	 * the correct translation. You MUST OMIT it in the translated string. */
 	{ N_("select fonts for|Armenian"),				"x-armn" },
@@ -108,7 +107,6 @@ static const EphyFontsLanguageInfo font_languages [] =
 	/* Translators: The text before the "|" is context to help you decide on
 	 * the correct translation. You MUST OMIT it in the translated string. */
 	{ N_("select fonts for|Malayalam"),				"x-mlym" },
-#endif /* HAVE_GECKO_1_8 */
 	/* Translators: The text before the "|" is context to help you decide on
 	 * the correct translation. You MUST OMIT it in the translated string. */
 	{ N_("select fonts for|Western"),				"x-western" },
