@@ -1,5 +1,5 @@
 /* 
- *  Copyright (C) 2002 Olivier Martin <omartin@ifrance.com>
+ *  Copyright © 2002 Olivier Martin <omartin@ifrance.com>
  *            (C) 2002 Jorn Baayen <jorn@nl.linux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -16,9 +16,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-filter.c,v 1.4 2003/12/16 17:29:40 marco Exp $
+ *  $Id: ephy-node-filter.c 6588 2006-09-13 11:34:25Z chpe $
  */
 
+#include "config.h"
+
 #include <stdlib.h>
 #include <string.h>
 #include <stdarg.h>
@@ -39,12 +41,12 @@ enum
 
 #define EPHY_NODE_FILTER_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_NODE_FILTER, EphyNodeFilterPrivate))
 
-struct EphyNodeFilterPrivate
+struct _EphyNodeFilterPrivate
 {
 	GPtrArray *levels;
 };
 
-struct EphyNodeFilterExpression
+struct _EphyNodeFilterExpression
 {
 	EphyNodeFilterExpressionType type;
 
@@ -77,11 +79,11 @@ static guint ephy_node_filter_signals[LAST_SIGNAL] = { 0 };
 GType
 ephy_node_filter_get_type (void)
 {
-	static GType ephy_node_filter_type = 0;
+	static GType type = 0;
 
-	if (ephy_node_filter_type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyNodeFilterClass),
 			NULL,
@@ -94,12 +96,12 @@ ephy_node_filter_get_type (void)
 			(GInstanceInitFunc) ephy_node_filter_init
 		};
 
-		ephy_node_filter_type = g_type_register_static (G_TYPE_OBJECT,
-							      "EphyNodeFilter",
-							      &our_info, 0);
+		type = g_type_register_static (G_TYPE_OBJECT,
+					       "EphyNodeFilter",
+					       &our_info, 0);
 	}
 
-	return ephy_node_filter_type;
+	return type;
 }
 
 static void
@@ -139,7 +141,7 @@ ephy_node_filter_finalize (GObject *object)
 
 	ephy_node_filter_empty (filter);
 
-	g_ptr_array_free (filter->priv->levels, FALSE);
+	g_ptr_array_free (filter->priv->levels, TRUE);
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -147,14 +149,7 @@ ephy_node_filter_finalize (GObject *object)
 EphyNodeFilter *
 ephy_node_filter_new (void)
 {
-	EphyNodeFilter *filter;
-
-	filter = EPHY_NODE_FILTER (g_object_new (EPHY_TYPE_NODE_FILTER,
-					       NULL));
-
-	g_return_val_if_fail (filter->priv != NULL, NULL);
-
-	return filter;
+	return EPHY_NODE_FILTER (g_object_new (EPHY_TYPE_NODE_FILTER, NULL));
 }
 
 void
@@ -165,6 +160,7 @@ ephy_node_filter_add_expression (EphyNodeFilter *filter,
 	while (level >= filter->priv->levels->len)
 		g_ptr_array_add (filter->priv->levels, NULL);
 
+	/* FIXME bogosity! This only works because g_list_append (x, data) == x */
 	g_ptr_array_index (filter->priv->levels, level) =
 		g_list_append (g_ptr_array_index (filter->priv->levels, level), exp);
 }
@@ -445,7 +441,7 @@ ephy_node_filter_expression_evaluate (EphyNodeFilterExpression *exp,
 
 		prop = ephy_node_get_property_int (node,
 						 exp->args.prop_args.prop_id);
-		g_print ("%d %d\n", prop, exp->args.prop_args.second_arg.number);
+
 		return (prop < exp->args.prop_args.second_arg.number);
 	}
 	default:
