@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-stock-icons.c,v 1.26 2006/12/08 18:09:38 chpe Exp $
+ *  $Id: ephy-stock-icons.c 6761 2006-12-19 17:03:22Z lferrett $
  */
 
 #include "config.h"
@@ -41,7 +41,6 @@ ephy_stock_icons_init (void)
 	{
 		STOCK_NEW_TAB,
 		STOCK_NEW_WINDOW,
-		STOCK_VIEW_SOURCE,
 		STOCK_SEND_MAIL,
 		STOCK_ADD_BOOKMARK,
 		STOCK_BOOKMARK,
@@ -49,7 +48,6 @@ ephy_stock_icons_init (void)
 		STOCK_LOCK_INSECURE,
 		STOCK_LOCK_SECURE,
 		STOCK_LOCK_BROKEN,
-		STOCK_DRAG_MODE,
 	};
 
 	static const GtkStockItem items[] =
