@@ -16,11 +16,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks-ui.c,v 1.14.4.1 2006/09/13 11:49:01 chpe Exp $
+ *  $Id: ephy-bookmarks-ui.c 6778 2007-01-02 19:47:49Z diegoe $
  */
 
 #include "config.h"
 
+#include "eel-gconf-extensions.h"
 #include "ephy-bookmarks.h"
 #include "ephy-bookmarks-ui.h"
 #include "ephy-bookmarks-menu.h"
@@ -43,12 +44,14 @@
 #include "ephy-file-helpers.h"
 #include "ephy-gui.h"
 #include "ephy-stock-icons.h"
+#include "ephy-prefs.h"
 #include "egg-editable-toolbar.h"
 
 #include <string.h>
 #include <glib/gi18n.h>
 #include <gtk/gtkmain.h>
 
+
 #define BM_WINDOW_DATA_KEY "bookmarks-window-data"
 
 typedef struct
@@ -429,6 +432,9 @@ ephy_bookmarks_ui_add_bookmark (GtkWindow *parent,
 				const char *location, 
 				const char *title)
 {
+
+	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING)) return;
+	
 	EphyBookmarks *bookmarks;
 	EphyNode *bookmark;
 	GtkWidget *dialog;
