@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-notebook.c,v 1.96 2006/11/12 13:26:52 ryanl Exp $
+ *  $Id: ephy-notebook.c 6747 2006-12-17 19:13:13Z chpe $
  */
 
 #include "config.h"
@@ -54,6 +54,9 @@
 
 #define INSANE_NUMBER_OF_URLS 20
 
+/* Tooltip related */
+#define TOOLTIP_MAX_LENGTH 256
+
 /* Until https://bugzilla.mozilla.org/show_bug.cgi?id=296002 is fixed */
 #define KEEP_TAB_IN_SAME_TOPLEVEL
 
@@ -441,7 +444,14 @@ notebook_drag_data_received_cb (GtkWidget* widget, GdkDragContext *context,
 	}
 	else
 	{
-		g_return_if_reached ();
+		char *text;
+	       
+		text = (char *) gtk_selection_data_get_text (selection_data);
+		if (text != NULL) {
+			ephy_link_open (EPHY_LINK (notebook), text, tab,
+					tab ? 0 : EPHY_LINK_NEW_TAB);
+			g_free (text);
+		}
 	}
 }
 
@@ -484,6 +494,9 @@ ephy_notebook_init (EphyNotebook *notebook)
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
 
 	notebook->priv->title_tips = gtk_tooltips_new ();
+	gtk_tooltips_force_window (notebook->priv->title_tips);
+	gtk_label_set_max_width_chars (GTK_LABEL (notebook->priv->title_tips->tip_label), TOOLTIP_MAX_LENGTH);
+	gtk_label_set_ellipsize (GTK_LABEL (notebook->priv->title_tips->tip_label), PANGO_ELLIPSIZE_END);
 	g_object_ref_sink (notebook->priv->title_tips);
 
 	notebook->priv->show_tabs = TRUE;
@@ -504,6 +517,7 @@ ephy_notebook_init (EphyNotebook *notebook)
 			   GTK_DEST_DEFAULT_DROP,
 			   url_drag_types, G_N_ELEMENTS (url_drag_types),
 			   GDK_ACTION_MOVE | GDK_ACTION_COPY);
+	gtk_drag_dest_add_text_targets (GTK_WIDGET(notebook));
 
 	notebook->priv->tabs_vis_notifier_id = eel_gconf_notification_add
 		(CONF_ALWAYS_SHOW_TABS_BAR,
@@ -566,7 +580,7 @@ static void
 sync_label (EphyTab *tab, GParamSpec *pspec, GtkWidget *proxy)
 {
 	GtkWidget *label, *ebox;
-	GtkTooltips *tips;	
+	GtkTooltips *tips;
 	const char *title;
 
 	ebox = GTK_WIDGET (g_object_get_data (G_OBJECT (proxy), "label-ebox"));
@@ -688,6 +702,7 @@ build_tab_label (EphyNotebook *nb, EphyTab *tab)
 	gtk_drag_dest_set (hbox, GTK_DEST_DEFAULT_ALL,
 			   url_drag_types, G_N_ELEMENTS (url_drag_types),
 			   GDK_ACTION_MOVE | GDK_ACTION_COPY);
+	gtk_drag_dest_add_text_targets (hbox);
 
 	gtk_widget_show (hbox);
 	gtk_widget_show (label_ebox);
