@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: popup-commands.c 6799 2007-01-08 23:01:43Z diegoe $
+ *  $Id: popup-commands.c 6798 2007-01-08 23:01:05Z diegoe $
  */
 
 #include "config.h"
@@ -167,6 +167,24 @@ popup_cmd_copy_link_address (GtkAction *action,
 	}
 }
 
+static void
+save_property_url_completed_cb (EphyEmbedPersist *persist)
+{
+	if (!(ephy_embed_persist_get_flags (persist) & 
+				EPHY_EMBED_PERSIST_ASK_DESTINATION))
+	{
+		const char *dest;
+		guint32 user_time;
+
+		user_time = ephy_embed_persist_get_user_time (persist);
+		dest = ephy_embed_persist_get_dest (persist);
+		g_return_if_fail (dest != NULL);
+
+		eel_gconf_get_string (CONF_STATE_DOWNLOAD_DIR);
+		ephy_file_browse_to (dest, user_time);
+	}
+}
+
 static void
 save_property_url (GtkAction *action,
 		   const char *title,
@@ -201,6 +219,9 @@ save_property_url (GtkAction *action,
 		(persist, CONF_STATE_SAVE_DIR);
 	ephy_embed_persist_set_source (persist, location);
 
+	g_signal_connect (persist, "completed",
+			  G_CALLBACK (save_property_url_completed_cb), NULL);
+
 	ephy_embed_persist_save (persist);
 
 	g_object_unref (G_OBJECT(persist));
